======
Binary
======

The following methods are available under the `Series.bin` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.bin.contains
    Series.bin.decode
    Series.bin.encode
    Series.bin.ends_with
    Series.bin.size
    Series.bin.starts_with
